/**
 * Tela de modelo com um componente de modelo
 *
 * @author               João Leão, Celso Correa, Rafael Araujo
 * @param onSelectImage  Função chamada quando uma imagem é selecionada;
 *                       recebe um objeto com os campos `uri` e `type`
 * @example              <AddImageComponent onSelectImage={(imgObj) => setImageForStep(step, imgObj)}/>
 */

import React from 'react';
import { StyleSheet, View, TouchableOpacity, Text, Alert } from 'react-native';
import Icon from 'react-native-vector-icons/Feather';
import * as ImagePicker from 'expo-image-picker';
import colors from '../constants/colors';

export default function AddImageComponent({ onSelectImage, value }) {
  const showPicker = async () => {
    const permission = await ImagePicker.requestCameraRollPermissionsAsync();
    if (permission.status !== ImagePicker.PermissionStatus.GRANTED) {
      Alert.alert('Precisamos de permissão para acessar a galeria', null, [
        { text: 'OK' },
      ]);
      return;
    }

    const result = await ImagePicker.launchImageLibraryAsync({
      allowsMultipleSelection: false,
      mediaTypes: ImagePicker.MediaTypeOptions.Images,
    });

    if (result.cancelled) {
      return;
    }

    if (onSelectImage) {
      onSelectImage({
        uri: result.uri,
        type: `image/${result.uri.split('.').pop().toLowerCase()}`,
      });
    }
  };

  return (
    <TouchableOpacity style={styles.input} onPress={showPicker}>
      <Text style={[styles.text, value && styles.textSelected]}>
        {value ? 'Imagem Selecionada' : 'Selecionar Imagem'}
      </Text>

      <View style={styles.icon}>
        <Icon name="upload-cloud" size={25} color="white"></Icon>
      </View>
    </TouchableOpacity>
  );
}

const styles = StyleSheet.create({
  input: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'flex-end',
    marginBottom: 30,
  },
  icon: {
    backgroundColor: colors.primary,
    padding: 8,
    borderBottomRightRadius: 4,
    borderTopRightRadius: 4,
  },
  text: {
    color: colors.textPlaceHolder,
    fontSize: 18,
    borderBottomColor: colors.primary,
    borderBottomWidth: 1,
    flex: 1,
    paddingBottom: 8,
  },
  textSelected: {
    color: colors.text,
  },
});
