/**
 * Componente de card para a seleção dos apps
 *
 * @author               Enzo Russo e João Leão
 * @param id             ID do card
 * @param image          Imagem do app
 * @param name           Nome do app
 * @param state          callback function
 * @param startSelected  OPCIONAL, caso o card sseja iniciado selecionado
 *
 * @example              <CardComponent name="YouTube" image={nome_da_imagem_importada}/>
 *
 *                       LEMBRANDO: O nome_da_imagem_importada QUE SERÁ PASSADO NA image={}
 *                       DEVERÁ SER IMPORTADO DA SEGUINTE MANEIRA:
 *                       import youtube from '../../assets/youtube.png';
 *                       DEPOIS DISSO, BASTA USAR image={youtube}
 */

import React, { useState } from 'react';
import {
  StyleSheet,
  TouchableOpacity,
  Text,
  Image,
  Platform,
  Dimensions,
} from 'react-native';
import colors from '../constants/colors';

export default function CardComponent({
  id,
  name,
  image,
  startSelected,
  onStateChange,
}) {
  const [selected, setSelected] = useState(startSelected);

  function cardClick() {
    setSelected(!selected);
    onStateChange(selected, id);
  }

  return (
    <TouchableOpacity
      style={[styles.card, selected && styles.selected]}
      onPress={_e => cardClick()}
      activeOpacity={1}
    >
      <Image style={styles.cardImage} source={image} />
      <Text style={styles.appName}>{name}</Text>
    </TouchableOpacity>
  );
}

const width = Dimensions.get('screen').width - 40;
const cardSize = width * 0.3;

const styles = StyleSheet.create({
  card: {
    backgroundColor: colors.background,
    borderRadius: 15,
    width: cardSize,
    height: cardSize,
    margin: 5,
    alignItems: 'center',
    justifyContent: 'center',
    elevation: 9,
    borderWidth: 3,
    borderColor: colors.transparent,
    ...Platform.select({
      ios: {
        shadowColor: colors.text,
        shadowOpacity: 0.25,
        shadowOffset: { width: 0, height: 1 },
        shadowRadius: 4,
      },
    }),
  },
  cardImage: {
    width: 40,
    height: 40,
  },
  appName: {
    fontSize: 18,
    color: colors.text,
    textAlign: 'center',
  },
  selected: {
    borderColor: colors.selected,
    ...Platform.select({
      ios: {
        shadowColor: colors.selected,
      },
    }),
  },
});
