/**
 * Componente que cria uma Lista do component ItemListComponent (lista de tutoriais)
 *
 * @author           Eduardo Cardoso
 * @param appoios      OBRIGATORIO - Array com os dados dos tutoriais
 * @param action       OBRIGATORIO - ação do botão do item da lista
 *
 * @example           Exemplo de array:
 *                        [
 *                           {
 *                             "id": 1,
 *                             "title": "Como apagar aplicativos?"
 *                           },
 *                           {
 *                             "id": 2,
 *                             "title": "Como inverte a câmera do celular?"
 *                           }
 *                         ]
 * @example          <ListComponent
 *                     appoios={arrayData}
 *                     action={function}
 *                   />
 */

import React from 'react';

import ItemListComponent from './ItemListComponent';
import { View, FlatList } from 'react-native';

export default function ListComponent({ appoios = [], action }) {
  function renderAppoio(appoio) {
    return (
      <ItemListComponent
        key={appoio.id + appoio.appoioName}
        id={appoio.id}
        title={appoio.appoioName}
        action={action}
      />
    );
  }

  return (
    <View>
      <FlatList
        data={appoios}
        renderItem={({ item: appoio }) => renderAppoio(appoio)}
        keyExtractor={appoio => appoio.id + appoio.appoioName}
      />
    </View>
  );
}
