/**
 * Componente de modelo que cria uma área de texto
 *
 * @author              Enzo Russo
 * @param sendText      Props para enviar texto do componente filho ao pai
 * @param name          variável para criar nome do passo
 * @example             <TextAreaComponent sendText={function}
 *                        name = "Passo X" />
 */

import React from 'react';
import {
  View,
  StyleSheet,
  Text,
  TextInput,
  TouchableOpacity,
} from 'react-native';
import colors from '../constants/colors';
import Icon from 'react-native-vector-icons/Feather';

export default function TextAreaComponent({ sendText, name, trash, value }) {
  const [text, setText] = React.useState(value);

  function handleText(text) {
    setText(text);
    sendText(text);
  }

  return (
    <View style={styles.screen}>
      <View style={styles.title}>
        <Text style={styles.passo}>{name}</Text>

        {trash && (
          <TouchableOpacity onPress={trash}>
            <Icon name={'trash-2'} style={styles.icon} />
          </TouchableOpacity>
        )}
      </View>

      <TextInput
        value={text || value}
        style={styles.input}
        multiline={true}
        placeholderTextColor="#989898"
        placeholder="Descreva esse passo"
        onChangeText={text => handleText(text)}
      />
    </View>
  );
}

const styles = StyleSheet.create({
  screen: {
    marginBottom: 30,
  },
  passo: {
    fontSize: 18,
    color: colors.textPlaceHolder,
    marginBottom: 10,
  },
  input: {
    padding: 10,
    backgroundColor: colors.background,
    maxWidth: '100%',
    fontSize: 18,
    borderRadius: 10,
    borderColor: colors.primary,
    borderWidth: 1,
  },
  title: {
    flexDirection: 'row',
    justifyContent: 'space-between',
  },
  icon: {
    fontSize: 25,
    color: colors.primary,
  },
});
