/**
 * Tela de confirmacao para envio de appoio
 *
 * @author            João Leão
 * @example           <AppoioConfirmationScreen/>
 */

import React from 'react';
import { View, Text, Image, StyleSheet } from 'react-native';
import { CommonActions } from '@react-navigation/native';

import Header from '../components/HeaderComponent';
import Body from '../components/BodyComponent';
import ButtonComponent from '../components/ButtonComponent';
import colors from '../constants/colors';

export default function AppoioConfirmationScreen({ navigation }) {
  function conclude() {
    navigation.dispatch(
      CommonActions.reset({
        index: 0,
        routes: [{ name: 'AppoioBasicScreen' }],
      }),
    );
  }
  return (
    <View style={styles.screen}>
      <Header large>
        <Text style={styles.title}>
          Obrigado por enviar um <Text style={styles.textBold}>Appoio</Text>
        </Text>
      </Header>
      <Body
        buttonAction={conclude}
        buttonText="Enviar Outro Appoio"
        buttonBackgroundColor={colors.primary}
        buttonTextColor={colors.textWhite}
      >
        <Image
          style={{ alignSelf: 'center', width: 250, height: 250 }}
          source={require('../../assets/logo.png')}
        />
        <Text style={styles.message}>
          Seu <Text style={styles.textBold}>Appoio</Text> será avaliado e
          publicado em breve!
        </Text>
      </Body>
    </View>
  );
}
const styles = StyleSheet.create({
  screen: {
    flex: 1,
    backgroundColor: colors.primary,
    alignItems: 'center',
  },
  title: {
    color: colors.textWhite,
    fontSize: 30,
    textAlign: 'center',
  },
  message: {
    color: colors.text,
    fontSize: 30,
    textAlign: 'center',
  },
  textBold: {
    fontWeight: 'bold',
  },
  content: {
    alignItems: 'center',
    justifyContent: 'space-around',
    flex: 1,
  },
});
