/**
 * Tela de modelo com um componente de modelo
 *
 * @author            Marlon Saldanha
 * @example           <CuradoriaScreen/>
 */

import React, { useCallback, useEffect, useState } from 'react';
import { View, Image, StyleSheet, Text } from 'react-native';
import { useFocusEffect } from '@react-navigation/native';
import HeaderComponent from '../components/HeaderComponent';
import Logo from '../assets/logo.png';
import colors from '../constants/colors';
import BodyComponent from '../components/BodyComponent';
import LoaderComponent from '../components/LoaderComponent';
import api from '../api';
import TutorialCard from '../components/TutorialCard';

export default function CuradoriaScreen({ navigation }) {
  const [tutorials, setTutorials] = useState([]);
  const [isLoading, setIsLoading] = useState(true);

  // recarregar sempre que a tela entrar em foco
  useFocusEffect(
    useCallback(() => {
      loadUnapprovedTutorials();
    }, []),
  );

  useEffect(() => {
    loadUnapprovedTutorials();
  }, [setTutorials, setIsLoading]);

  async function loadUnapprovedTutorials() {
    setIsLoading(true);
    const response = await api.get('tutorial/categories/0');
    setTutorials(response.data.data);
    setIsLoading(false);
  }

  function formatDate(date) {
    date = String(date).split(' ');
    var days = String(date[0]).split('-');
    return [parseInt(days[2]), '/', parseInt(days[1]), '/', parseInt(days[0])];
  }
  const emptyMessage = (
    text = 'Não existem tutoriais para serem avaliados',
  ) => (
    <View style={styles.emptyMessageContainer}>
      <Text style={styles.emptyMessage}>{text}</Text>
    </View>
  );

  return (
    <View style={styles.screen}>
      <HeaderComponent>
        <Image source={Logo} style={styles.logo} />
      </HeaderComponent>
      <BodyComponent>
        {isLoading ? (
          <LoaderComponent color={colors.primary} isActivityIndicator="true" />
        ) : tutorials.length > 0 ? (
          <View>
            {tutorials.map(tutorial => (
              <TutorialCard
                key={tutorial.id}
                trusteeship
                action={e =>
                  navigation.navigate('TutorialScreen', {
                    isAdmin: true,
                    id: tutorial.id,
                  })
                }
                date={formatDate(tutorial.date)}
                author={tutorial.user.name}
                title={tutorial.appoioName}
                category={tutorial.category}
              />
            ))}
          </View>
        ) : (
          emptyMessage()
        )}
      </BodyComponent>
    </View>
  );
}

const styles = StyleSheet.create({
  screen: {
    flex: 1,
    backgroundColor: colors.primary,
  },
  emptyMessageContainer: {
    paddingTop: 50,
  },
  emptyMessage: {
    color: colors.textDisabled,
    fontSize: 20,
    fontWeight: 'bold',
    textAlign: 'center',
  },
});
